<?php
use services\navigation\MenuItem;

if ( !defined( 'IN_CMS' ) ) {
    exit();
}

\IoC::resolve( 'eventmediator' )->attach( 'before_route', function( FastRoute\RouteCollector $r, $request, $response ) {
    $r->get( 'blog/post/list', 'plugins\\blog\\controllers\PostController@list' );
    $r->get( 'blog/post/add', 'plugins\\blog\\controllers\PostController@addform' );
    $r->post( 'blog/post/add', 'plugins\\blog\\controllers\PostController@add' );
    $r->get( 'blog/post/update/{id:\\d+}', 'plugins\\blog\\controllers\PostController@updateform' );
    $r->post( 'blog/post/update/{id:\\d+}', 'plugins\\blog\\controllers\PostController@update' );
    $r->get( 'blog/post/delete/{id:\\d+}', 'plugins\\blog\\controllers\PostController@delete' );
    $r->get( 'blog/post/show/{id:\\d+}', 'plugins\\blog\\controllers\PostController@show' );
    $r->get( 'blog/settings', 'plugins\\blog\\controllers\SettingsController@index' );
    $r->post( 'blog/settings', 'plugins\\blog\\controllers\SettingsController@update' );
    $r->get( 'blog', 'plugins\\blog\\controllers\PostController@index' );
    $r->get( 'blog/page/{page:\\d+}', 'plugins\\blog\\controllers\PostController@index' );
    $r->get( 'blog/tags/{tag:[\\wéèêëçàîôáúíóñ ]+}', 'plugins\\blog\\controllers\PostController@index' );
    $r->get( 'blog/tags/{tag:[\\wéèêëçàîôáúíóñ ]+}/{page:\\d+}', 'plugins\\blog\\controllers\PostController@index' );
    $r->get( 'blog/archive/{year:\\d+}/{month:\\d+}', 'plugins\\blog\\controllers\PostController@index' );
    $r->get( 'blog/{slug:[a-zA-Z0-9\\-]+}.html', 'plugins\\blog\\controllers\PostController@show' );
    $r->get( 'blog/comment/list', 'plugins\\blog\\controllers\\CommentController@list' );
    $r->post( 'blog/comment/add', 'plugins\\blog\\controllers\\CommentController@add' );
    $r->get( 'blog/comment/update/{id:\\d+}', 'plugins\\blog\\controllers\CommentController@updateform' );
    $r->post( 'blog/comment/update/{id:\\d+}', 'plugins\\blog\\controllers\CommentController@update' );
    $r->get( 'blog/comment/delete/{id:\\d+}', 'plugins\\blog\\controllers\CommentController@delete' );
    $r->get( 'public/css/blog/style.css', 'plugins\\blog\\controllers\\AssetsController@css' );
    return true;
});

\IoC::resolve( 'eventmediator' )->attach( 'after_initialize_backend_menu', function( services\navigation\Menu $backendMenu ) {
    $backendMenu->addItem( new MenuItem( 'blog' ) );
    $backendMenu->getItems()['blog']->addChild( new MenuItem( 'blog.posts', BASE_URL . 'blog/post/list' ) );
    $backendMenu->getItems()['blog']->addChild( new MenuItem( 'blog.comments', BASE_URL . 'blog/comment/list' ) );
    return true;
} );

\IoC::resolve( 'eventmediator' )->attach( 'check_template_used', function( $template, &$isUsed ) {
    $settings = \IoC::resolve( 'settings' );
    if ( in_array( $template->template_id, [$settings['blog.index_template'], $settings['blog.post_template'], $settings['blog.sidebar']] ) ) {
        $isUsed = true;
        return false;
    }
    return true;
} );

$logger = \IoC::resolve( 'logger' );
$logger->info( 'Plugin blog initialized.' );
